Info<< "Reading field p\n" << endl;
volScalarField p
(
    IOobject
    (
        "p",
        runTime.timeName(),
        mesh,
        IOobject::MUST_READ,
        IOobject::AUTO_WRITE
    ),
    mesh
);

Info<< "Reading field U.water\n" << endl;
volVectorField U
(
    IOobject
    (
        "U.water",
        runTime.timeName(),
        mesh,
        IOobject::MUST_READ,
        IOobject::AUTO_WRITE
    ),
    mesh
);

volVectorField gradP 
(
    IOobject
    (
        "gradP",
        runTime.timeName(),
        mesh,
        IOobject::NO_READ,
        IOobject::NO_WRITE
    ),
	fvc::grad(p)
);

#include "createPhi.H"

label pRefCell = 0;
scalar pRefValue = 0.0;
setRefCell(p, piso.dict(), pRefCell, pRefValue);
mesh.setFluxRequired(p.name());

singlePhaseTransportModel laminarTransport(U, phi);

autoPtr<incompressible::turbulenceModel> turbulence
(
    incompressible::turbulenceModel::New(U, phi, laminarTransport)
);

#include "createMRF.H"

volScalarField rhoc 
(
    IOobject
    (
        "rho.water",
        runTime.timeName(),
        mesh,
        IOobject::MUST_READ,
        IOobject::AUTO_WRITE
    ),
	mesh
);

volScalarField mu 
(
    IOobject
    (
        "mu.water",
        runTime.timeName(),
        mesh,
        IOobject::NO_READ,
        IOobject::NO_WRITE
    ),
	laminarTransport.nu()*rhoc
);

IOdictionary GPBEProperties
(
	IOobject
	(
		"GPBEProperties",
		runTime.constant(),
		mesh,
		IOobject::MUST_READ,
		IOobject::NO_WRITE
	)
);

autoPtr<MOM> GPBE 
(
	MOM::New(mesh, GPBEProperties)
); 

//- dummy for turbulence
volScalarField k 
(
    IOobject
    (
        "k.water",
        runTime.timeName(),
        mesh,
        IOobject::NO_READ,
        IOobject::NO_WRITE
    ),
	mu
);

#include "readGravitationalAcceleration.H"

Switch calculatePU
(
	GPBEProperties.lookupOrDefault("calculatePU", false)
);

surfaceScalarField phid
(
    IOobject
    (
        "phi.air",
        runTime.timeName(),
        mesh,
        IOobject::NO_READ,
        IOobject::NO_WRITE
    ),
    linearInterpolate(U) & mesh.Sf()
);

