/*******************************************************************************
@GPBEFoam:		3D fully coupled Eulerian-QBMM library for multiphase flows

@Authors: 		Dongyue Li (HZDR & Dyfluid, Programmer)
				Daniele Marchisio (Politecnico di Torino, Co-PI)
				Christian Hasse (TU Darmstadt, Co-PI)
				Dirk Lucas (Helmholtz-Zentrum Dresden-Rossendorf, Investor)

@Reference:  	D. Li, D. Marchisio, C. Hasse, D. Lucas, twoWayGPBEFoam and 
				oneWayGPBEFoam: open-source Eulerian-QBMM solvers for multiphase 
				flows. Computer Physics Communication, Submitted

@History:    	ver 1.0, 07/31/18 

@Info:			The released Eulerian-QBMM library is based on OpenFOAM-5.x. 
				oneWayGPBEFoam can be employed to simulate one-way coupled 
				problems. twoWayGPBEFoam can be employed to simulate two-way 
				coupled problems.

				twoWayGPBEFoam: 3D two-way coupled Eulerian-QBMM solver for 
				multiphase flows.
*******************************************************************************/


#include "fvCFD.H"
#include "singlePhaseTransportModel.H"
#include "turbulentTransportModel.H"
#include "pisoControl.H"
#include "fvOptions.H"
#include "MOM.H"


int main(int argc, char *argv[])
{
    #include "postProcess.H"

    #include "setRootCase.H"
    #include "createTime.H"
    #include "createMesh.H"
    #include "createControl.H"
    #include "createFields.H"
    #include "createFvOptions.H"
    #include "initContinuityErrs.H"

    turbulence->validate();

    Info<< "\nStarting time loop\n" << endl;

    while (runTime.loop())
    {
        Info<< "Time = " << runTime.timeName() << nl << endl;

		if (calculatePU)
		{
            #include "CourantNo.H"

			// Pressure-velocity PISO corrector
			{
				#include "UEqn.H"

				// --- PISO loop
				while (piso.correct())
				{
					#include "pEqn.H"
				}
			}

			laminarTransport.correct();
			turbulence->correct();
		}

        GPBE->solve(); 

        #include "particleCourantNo.H"

        runTime.write();

        Info<< "ExecutionTime = " << runTime.elapsedCpuTime() << " s"
            << "  ClockTime = " << runTime.elapsedClockTime() << " s"
            << nl << endl;
    }

    Info<< "End\n" << endl;

    return 0;
}


// ************************************************************************* //
