/*******************************************************************************
@GPBEFoam:           3D fully coupled Eulerian-QBMM library for multiphase flows

@Authors:            Dongyue Li (HZDR & Dyfluid, Programmer)
                     Daniele Marchisio (Politecnico di Torino, Co-PI)
                     Christian Hasse (TU Darmstadt, Co-PI)
                     Dirk Lucas (Helmholtz-Zentrum Dresden-Rossendorf, Investor)

@Reference:  	     D. Li, D. Marchisio, C. Hasse, D. Lucas, twoWayGPBEFoam and 
                     oneWayGPBEFoam: open-source Eulerian-QBMM solvers for 
                     multiphase flows. Computer Physics Communication, Submitted

@History:            ver 1.0, 07/31/18 

@Info:	             The released Eulerian-QBMM library is based on OpenFOAM-5.x 
                     oneWayGPBEFoam can be employed to simulate one-way coupled 
                     problems. twoWayGPBEFoam can be employed to simulate
                     two-way coupled problems.
*******************************************************************************/


#include "fvCFD.H"
#include "singlePhaseTransportModel.H"
#include "PhaseIncompressibleTurbulenceModel.H"
#include "pimpleControl.H"
#include "MOM.H"
#include "fixedValueFvsPatchFields.H"


int main(int argc, char *argv[])
{
    #include "postProcess.H"
    #include "setRootCase.H"
    #include "createTime.H"
    #include "createMesh.H"
    #include "createControl.H"
    #include "createTimeControls.H"
    #include "createFields.H"
    #include "initContinuityErrs.H"

    Info<< "\nStarting time loop\n" << endl;

    while (runTime.run())
    {
        #include "readTimeControls.H"
        #include "CourantNo.H"
        #include "setDeltaT.H"

        runTime++;

        Info<< "Time = " << runTime.timeName() << nl << nl;

        continuousPhaseTransport.correct();
        muc = rhoc*continuousPhaseTransport.nu();

        GPBE->solve();
 
        #include "particleCourantNo.H"

        alphacf = fvc::interpolate(GPBE->alphac());
        alphaPhic = alphacf*phic;
	
        while (pimple.loop())
        {
            #include "UcEqn.H"
      
            while (pimple.correct())
            {
                #include "pEqn.H"
            }

            if (pimple.turbCorr())
            {
                continuousPhaseTurbulence->correct();
            }
      	}

        runTime.write();

        Info<< "ExecutionTime = " << runTime.elapsedCpuTime() << " s"
        << "  ClockTime = " << runTime.elapsedClockTime() << " s"
        << nl << endl;
    }

    Info<< "End\n" << endl;

    return 0;
}


// ************************************************************************* //
