/*******************************************************************************
@GPBEFoam:           3D fully coupled Eulerian-QBMM library for multiphase flows

@Authors:            Dongyue Li (HZDR & Dyfluid, Programmer)
                     Daniele Marchisio (Politecnico di Torino, Co-PI)
                     Christian Hasse (TU Darmstadt, Co-PI)
                     Dirk Lucas (Helmholtz-Zentrum Dresden-Rossendorf, Investor)

@Reference:  	     D. Li, D. Marchisio, C. Hasse, D. Lucas, twoWayGPBEFoam and 
                     oneWayGPBEFoam: open-source Eulerian-QBMM solvers for 
                     multiphase flows. Computer Physics Communication, Submitted

@History:            ver 1.0, 07/31/18 

@Info:	             The released Eulerian-QBMM library is based on OpenFOAM-5.x 
                     oneWayGPBEFoam can be employed to simulate one-way coupled 
                     problems. twoWayGPBEFoam can be employed to simulate
                     two-way coupled problems.
*******************************************************************************/


inline const Foam::PtrList<Foam::volScalarField>& 
Foam::MOM::Kd() const
{
    return forceFrame_.Kd();
}


inline const Foam::PtrList<Foam::volVectorField>& 
Foam::MOM::liftF() const
{
    return forceFrame_.liftF();
}


inline const Foam::PtrList<Foam::volVectorField>& 
Foam::MOM::wallLubF() const
{
    return forceFrame_.wallLubF();
}


inline const Foam::PtrList<Foam::volVectorField>& 
Foam::MOM::turbulentDisF() const
{
    return forceFrame_.turbulentDisF();
}


inline const Foam::PtrList<Foam::volScalarField>& 
Foam::MOM::mom() const
{
    return M_;
}


inline const Foam::volScalarField& Foam::MOM::alphac() const
{
    return beta_;
}


inline const Foam::dimensionedScalar& Foam::MOM::rhod() const
{
    return rhod_;
}


inline const Foam::volScalarField& Foam::MOM::rhoc() const
{
    return rhoc_;
}


inline const Foam::PtrList<Foam::volScalarField>& 
Foam::MOM::alphaSequence() const
{
    return alphaSequence_;
}


inline const Foam::volScalarField& Foam::MOM::weightedAlpha() const
{
    return alpha_;
}


inline const Foam::PtrList<Foam::volScalarField>& Foam::MOM::weights() const
{
    return weis_;
}


inline const Foam::PtrList<Foam::volScalarField>& Foam::MOM::abscissas() const
{
    return abs_;
}


inline const Foam::volVectorField& Foam::MOM::particleU
(
    const scalar& kth
) const
{
    return particleU_[kth];
}
