/*******************************************************************************
@GPBEFoam:           3D fully coupled Eulerian-QBMM library for multiphase flows

@Authors:            Dongyue Li (HZDR & Dyfluid, Programmer)
                     Daniele Marchisio (Politecnico di Torino, Co-PI)
                     Christian Hasse (TU Darmstadt, Co-PI)
                     Dirk Lucas (Helmholtz-Zentrum Dresden-Rossendorf, Investor)

@Reference:          D. Li, D. Marchisio, C. Hasse, D. Lucas, twoWayGPBEFoam and 
                     oneWayGPBEFoam: open-source Eulerian-QBMM solvers for 
                     multiphase flows. Computer Physics Communication, Submitted

@History:            ver 1.0, 07/31/18 

@Info:               The released Eulerian-QBMM library is based on OpenFOAM-5.x 
                     oneWayGPBEFoam can be employed to simulate one-way coupled 
                     problems. twoWayGPBEFoam can be employed to simulate
                     two-way coupled problems.
*******************************************************************************/


#include "QMOM.H"
#include "addToRunTimeSelectionTable.H"
#include "fvc.H"
#include "zeroGradientFvPatchFields.H"
#include "uniformDimensionedFields.H"
#include "fixedValueFvPatchFields.H"    
#include "wallFvPatch.H"


namespace Foam
{
    defineTypeNameAndDebug(QMOM, 0);

    addToRunTimeSelectionTable
    (
        MOM,
        QMOM,
        dictionary
    );
}


void Foam::QMOM::calculateAbs
(
    const label& cellI
)
{
    momInvPtr_->solve
    (
        weis_,
        abs_,
        M_,
        numberOfAbs_,
        cellI
    );

    if (nodes_ == 1)
    {
        d32_.ref()[cellI] = abs_[0][cellI];
    }
    else
    {
        d32_.ref()[cellI] = M_[3][cellI]/M_[2][cellI];
    }
}


Foam::QMOM::QMOM
(
    const fvMesh& mesh,
    const dictionary& MOMProperties
)
:
    MOM(mesh, MOMProperties)
{
    Info<<"\nQMOM constructing function\n";
}
