/*******************************************************************************
@GPBEFoam:           3D fully coupled Eulerian-QBMM library for multiphase flows

@Authors:            Dongyue Li (HZDR & Dyfluid, Programmer)
                     Daniele Marchisio (Politecnico di Torino, Co-PI)
                     Christian Hasse (TU Darmstadt, Co-PI)
                     Dirk Lucas (Helmholtz-Zentrum Dresden-Rossendorf, Investor)

@Reference:          D. Li, D. Marchisio, C. Hasse, D. Lucas, twoWayGPBEFoam and 
                     oneWayGPBEFoam: open-source Eulerian-QBMM solvers for 
                     multiphase flows. Computer Physics Communication, Submitted

@History:            ver 1.0, 07/31/18 

@Info:               The released Eulerian-QBMM library is based on OpenFOAM-5.x 
                     oneWayGPBEFoam can be employed to simulate one-way coupled 
                     problems. twoWayGPBEFoam can be employed to simulate
                     two-way coupled problems.
*******************************************************************************/

#ifndef QMOM_H
#define QMOM_H

#include "MOM.H"
#include "momentsInversion.H"
#include "Vikas.H"
#include "breakageModel.H"
#include "coalescenceModel.H"
#include "daughterSizeDistributionModel.H"
#include "timeScheme.H"


namespace Foam
{

class QMOM
:
    public MOM
{
    //- Private data

protected:

    //- Protected member functions

        //- Disallow copy construct
        QMOM(const QMOM&);

        //- Disallow default bitwise assignment
        void operator=(const QMOM&);


public:

    //- Runtime type information
    TypeName("QMOM");

    //- Constructers

        QMOM
        (
            const fvMesh& mesh,
            const dictionary& MOMProperties
        );

        virtual ~QMOM()
        {}

    //- Member functions

        //- Update the abscissas and weights in cells
        virtual void calculateAbs(const label& cellI);


};


} // End namespace Foam


#endif
