/*******************************************************************************
@GPBEFoam:      3D fully coupled Eulerian-QBMM library for multiphase flows

@Authors:       Dongyue Li (HZDR & Dyfluid, Programmer)
                Daniele Marchisio (Politecnico di Torino, Co-PI)
                Christian Hasse (TU Darmstadt, Co-PI)
                Dirk Lucas (Helmholtz-Zentrum Dresden-Rossendorf, Investor)

@Reference:     D. Li, D. Marchisio, C. Hasse, D. Lucas, twoWayGPBEFoam and 
                oneWayGPBEFoam: open-source Eulerian-QBMM solvers for multiphase 
                flows. Computer Physics Communication, Submitted

@History:       ver 1.0, 07/31/18 

@Info:          The released Eulerian-QBMM library is based on OpenFOAM-5.x. 
                oneWayGPBEFoam can be employed to simulate one-way coupled 
                problems. twoWayGPBEFoam can be employed to simulate two-way 
                coupled problems.
*******************************************************************************/


#ifndef Vikas_H
#define Vikas_H

#include "surfaceFields.H"


namespace Foam
{

class Vikas
{
    //- Private members

        const fvMesh& mesh_;

        word schemeAbs;

        word schemeWei;

        word schemeU;

        word schemePhi;

        surfaceScalarField Pos;     

        surfaceScalarField Neg;     

        PtrList<tmp<surfaceScalarField>> phiUPos_;
        
        PtrList<tmp<surfaceScalarField>> phiUNeg_;
        
        PtrList<tmp<surfaceScalarField>> phiVPos_;
        
        PtrList<tmp<surfaceScalarField>> phiVNeg_;
        
        PtrList<tmp<surfaceScalarField>> phiWPos_;
        
        PtrList<tmp<surfaceScalarField>> phiWNeg_;

        dimensionedScalar phi_zero;
        
        PtrList<tmp<surfaceScalarField>> MfXPos_;
        
        PtrList<tmp<surfaceScalarField>> MfXNeg_;
        
        PtrList<tmp<surfaceScalarField>> MfYPos_;
        
        PtrList<tmp<surfaceScalarField>> MfYNeg_;
        
        PtrList<tmp<surfaceScalarField>> MfZPos_;
        
        PtrList<tmp<surfaceScalarField>> MfZNeg_;
        
        PtrList<tmp<surfaceScalarField>> abscissasfPos_;
        
        PtrList<tmp<surfaceScalarField>> abscissasfNeg_;
        
        PtrList<tmp<surfaceScalarField>> weightsfPos_;
        
        PtrList<tmp<surfaceScalarField>> weightsfNeg_;
        
        PtrList<surfaceVectorField> UP_;
        
        PtrList<surfaceVectorField> UN_;
        
    
public:

    //- Construct from components

        Vikas
        (
            const fvMesh& mesh,
            const scalar numberOfMom,
            const scalar numberOfAbs
        );

        virtual ~Vikas()
        {}


    //- Member functions

        //- Correct Flux
        virtual void correctFlux
        (
            const PtrList<volScalarField>& weights,
            const PtrList<volScalarField>& abscissas,
            const PtrList<volScalarField>& M,
            PtrList<surfaceScalarField>& mFluxX,
            PtrList<surfaceScalarField>& mFluxY,
            PtrList<surfaceScalarField>& mFluxZ,
            const PtrList<volVectorField>& particleU,
            const label pureMomentsNumber,
            const label nodes
        );

        void iniZero(const label kth);
};

}


#endif
