/*******************************************************************************
@GPBEFoam:           3D fully coupled Eulerian-QBMM library for multiphase flows

@Authors:            Dongyue Li (HZDR & Dyfluid, Programmer)
                     Daniele Marchisio (Politecnico di Torino, Co-PI)
                     Christian Hasse (TU Darmstadt, Co-PI)
                     Dirk Lucas (Helmholtz-Zentrum Dresden-Rossendorf, Investor)

@Reference:  	     D. Li, D. Marchisio, C. Hasse, D. Lucas, twoWayGPBEFoam and 
                     oneWayGPBEFoam: open-source Eulerian-QBMM solvers for 
                     multiphase flows. Computer Physics Communication, Submitted

@History:            ver 1.0, 07/31/18 

@Info:	             The released Eulerian-QBMM library is based on OpenFOAM-5.x 
                     oneWayGPBEFoam can be employed to simulate one-way coupled 
                     problems. twoWayGPBEFoam can be employed to simulate
                     two-way coupled problems.
*******************************************************************************/

#ifndef momentsInversion_H
#define momentsInversion_H

#include "scalarMatrices.H"
#include "eigenSolver.H"
#include "volFields.H"


namespace Foam
{

class momentsInversion
{

protected:


    //- Protected data
        
        //- Moments inversion algorithm
        word momInvModel_;

        //- Mesh
        const fvMesh& mesh_;


    //- Protected member functions

        //- Disallow copy construct
        momentsInversion(const momentsInversion&);

        //- Disallow default bitwise assignment
        void operator=(const momentsInversion&);

public:


    //- Runtime type information
    TypeName("momentsInversion");

        declareRunTimeSelectionTable
        (
            autoPtr,
            momentsInversion,
            dictionary,
            (
                const word& momInvModel,
                const fvMesh& mesh
            ),
            (momInvModel, mesh)
        );

        static autoPtr<momentsInversion> New
        (
            const word& momInvModel,
            const fvMesh& mesh
        );
        

    //- Constructers

        momentsInversion
        (
            const word& momInvModel,
            const fvMesh& mesh
        );

        virtual ~momentsInversion()
        {}


    //- Member functions

        //- Calculate weights and abs in cells
        void solve
        (
            PtrList<volScalarField>& weights,
            PtrList<volScalarField>& abscissas,
            PtrList<volScalarField>& moments,
            const label& numberOfAbs,
	        const label& cellI
        );

        //- wheeler or pd core algorithm
        virtual scalarSquareMatrix core
        (
            const label n,
            const scalar* mom
        ) = 0;

        //- Calculate weights and abs in boundaries
        void solveBoundary
        (
            PtrList<volScalarField>& weights,
            PtrList<volScalarField>& abscissas,
            PtrList<volScalarField>& moments,
            const label& numberOfAbs
        );

        //- Initilize weights and abs for fixed value 
        //- boundaries for initial time
        void initilizeWeiAbs
        (
            PtrList<volScalarField>& weights,
            PtrList<volScalarField>& abscissas,
            PtrList<volScalarField>& moments,
            const label& numberOfAbs
        );
};


} // End namespace Foam


#endif
