/*******************************************************************************
@GPBEFoam:           3D fully coupled Eulerian-QBMM library for multiphase flows

@Authors:            Dongyue Li (HZDR & Dyfluid, Programmer)
                     Daniele Marchisio (Politecnico di Torino, Co-PI)
                     Christian Hasse (TU Darmstadt, Co-PI)
                     Dirk Lucas (Helmholtz-Zentrum Dresden-Rossendorf, Investor)

@Reference:          D. Li, D. Marchisio, C. Hasse, D. Lucas, twoWayGPBEFoam and 
                     oneWayGPBEFoam: open-source Eulerian-QBMM solvers for 
                     multiphase flows. Computer Physics Communication, Submitted

@History:            ver 1.0, 07/31/18 

@Info:               The released Eulerian-QBMM library is based on OpenFOAM-5.x 
                     oneWayGPBEFoam can be employed to simulate one-way coupled 
                     problems. twoWayGPBEFoam can be employed to simulate
                     two-way coupled problems.
*******************************************************************************/

#ifndef pd_H
#define pd_H

#include "momentsInversion.H"


namespace Foam
{

class pd
:
    public momentsInversion
{


protected:


    //- Member functions

        //- Disallow copy construct
        pd(const pd&);

        //- Disallow default bitwise assignment
        void operator=(const pd&);

        //- Boundary weights for fixedValue
        double* weisBD_;

        //- Boundary abscissas for fixedValue
        double* absBD_;


public:

    //- Runtime type information
    TypeName("pd");
        

    //- Constructers

        pd
        (
            const word& momInvModel,
            const fvMesh& mesh
        );

        virtual ~pd()
        {}


    //- Member functions
        

        //- pd core algorithm
        scalarSquareMatrix core
        (
            const label n,
            const scalar* mom
        );

};


}


#endif
