/*******************************************************************************
@GPBEFoam:           3D fully coupled Eulerian-QBMM library for multiphase flows

@Authors:            Dongyue Li (HZDR & Dyfluid, Programmer)
                     Daniele Marchisio (Politecnico di Torino, Co-PI)
                     Christian Hasse (TU Darmstadt, Co-PI)
                     Dirk Lucas (Helmholtz-Zentrum Dresden-Rossendorf, Investor)

@Reference:  	     D. Li, D. Marchisio, C. Hasse, D. Lucas, twoWayGPBEFoam and 
                     oneWayGPBEFoam: open-source Eulerian-QBMM solvers for 
                     multiphase flows. Computer Physics Communication, Submitted

@History:            ver 1.0, 07/31/18 

@Info:	             The released Eulerian-QBMM library is based on OpenFOAM-5.x 
                     oneWayGPBEFoam can be employed to simulate one-way coupled 
                     problems. twoWayGPBEFoam can be employed to simulate
                     two-way coupled problems.
*******************************************************************************/

#include "SchillerNaumann.H"
#include "addToRunTimeSelectionTable.H"


namespace Foam
{
    defineTypeNameAndDebug(SchillerNaumann, 0);

    addToRunTimeSelectionTable
    (
        drag,
        SchillerNaumann,
        dictionary
    );
}


void Foam::SchillerNaumann::updateCdRe
(
    const label& cellI,
    const scalar& diameter,
    const scalar& Ur,
    const scalar& rhoc,
    const scalar& rhod,
    const scalar& muc,
    const scalar& alpha,
    const scalar& kth
) 
{
    scalar Re(Ur*diameter*rhoc/(muc + ROOTVSMALL));

    CdRe_[kth][cellI] = neg(Re - 1000)*24.0*(1.0 + 0.15*pow(Re, 0.687))
      + pos(Re - 1000)*0.44*max(Re, residualRe_);
}


Foam::SchillerNaumann::SchillerNaumann
(
    const dictionary& dragModels,
    const fvMesh& mesh,
    const bool registerObject
)
:
    drag(dragModels, mesh, registerObject),
    residualRe_(readScalar(dragModels.lookup("residualRe")))
{}
