/*******************************************************************************
@GPBEFoam:           3D fully coupled Eulerian-QBMM library for multiphase flows

@Authors:            Dongyue Li (HZDR & Dyfluid, Programmer)
                     Daniele Marchisio (Politecnico di Torino, Co-PI)
                     Christian Hasse (TU Darmstadt, Co-PI)
                     Dirk Lucas (Helmholtz-Zentrum Dresden-Rossendorf, Investor)

@Reference:  	     D. Li, D. Marchisio, C. Hasse, D. Lucas, twoWayGPBEFoam and 
                     oneWayGPBEFoam: open-source Eulerian-QBMM solvers for 
                     multiphase flows. Computer Physics Communication, Submitted

@History:            ver 1.0, 07/31/18 

@Info:	             The released Eulerian-QBMM library is based on OpenFOAM-5.x 
                     oneWayGPBEFoam can be employed to simulate one-way coupled 
                     problems. twoWayGPBEFoam can be employed to simulate
                     two-way coupled problems.
*******************************************************************************/

#include "constantDrag.H"
#include "addToRunTimeSelectionTable.H"


namespace Foam
{
    defineTypeNameAndDebug(constantDrag, 0);

    addToRunTimeSelectionTable
    (
        drag,
        constantDrag,
        dictionary
    );
}


void Foam::constantDrag::updateCdRe
(
    const label& cellI,
    const scalar& diameter,
    const scalar& Ur,
    const scalar& rhoc,
    const scalar& rhod,
    const scalar& muc,
    const scalar& alpha,
    const scalar& kth
) 
{
    CdRe_[kth][cellI] = 
        1.0/(C_*Foam::pow(diameter, 2.0/3.0))
       /0.75/muc*sqr(diameter);
}


Foam::constantDrag::constantDrag
(
    const dictionary& dragModels,
    const fvMesh& mesh,
    const bool registerObject
)
:
    drag(dragModels, mesh, registerObject),
    C_(readScalar(dragModels_.lookup("tau")))	
{}
