/*******************************************************************************
@GPBEFoam:           3D fully coupled Eulerian-QBMM library for multiphase flows

@Authors:            Dongyue Li (HZDR & Dyfluid, Programmer)
                     Daniele Marchisio (Politecnico di Torino, Co-PI)
                     Christian Hasse (TU Darmstadt, Co-PI)
                     Dirk Lucas (Helmholtz-Zentrum Dresden-Rossendorf, Investor)

@Reference:  	     D. Li, D. Marchisio, C. Hasse, D. Lucas, twoWayGPBEFoam and 
                     oneWayGPBEFoam: open-source Eulerian-QBMM solvers for 
                     multiphase flows. Computer Physics Communication, Submitted

@History:            ver 1.0, 07/31/18 

@Info:	             The released Eulerian-QBMM library is based on OpenFOAM-5.x 
                     oneWayGPBEFoam can be employed to simulate one-way coupled 
                     problems. twoWayGPBEFoam can be employed to simulate
                     two-way coupled problems.
*******************************************************************************/

#ifndef constantDrag_H
#define constantDrag_H

#include "drag.H"


namespace Foam
{


class constantDrag
:
    public drag
{
    //- Private data

        //- Relaxation time
        const scalar C_;


public:

    //- Runtime type information
    TypeName("constantDrag");


    //- Constructers

        constantDrag
        (
            const dictionary& dragModels,
            const fvMesh& mesh,
            const bool registerObject
        );

        virtual ~constantDrag()
        {}


    //- Member functions

        //- Calculate CdRe
        void updateCdRe
        (
            const label& cellI,
            const scalar& diameter,
            const scalar& Ur,
            const scalar& rhoc,
            const scalar& rhod,
            const scalar& muc,
            const scalar& alpha,
            const scalar& kth
        );
};


} // End namespace Foam


#endif
