/*******************************************************************************
@GPBEFoam:           3D fully coupled Eulerian-QBMM library for multiphase flows

@Authors:            Dongyue Li (HZDR & Dyfluid, Programmer)
                     Daniele Marchisio (Politecnico di Torino, Co-PI)
                     Christian Hasse (TU Darmstadt, Co-PI)
                     Dirk Lucas (Helmholtz-Zentrum Dresden-Rossendorf, Investor)

@Reference:  	     D. Li, D. Marchisio, C. Hasse, D. Lucas, twoWayGPBEFoam and 
                     oneWayGPBEFoam: open-source Eulerian-QBMM solvers for 
                     multiphase flows. Computer Physics Communication, Submitted

@History:            ver 1.0, 07/31/18 

@Info:	             The released Eulerian-QBMM library is based on OpenFOAM-5.x 
                     oneWayGPBEFoam can be employed to simulate one-way coupled 
                     problems. twoWayGPBEFoam can be employed to simulate
                     two-way coupled problems.
*******************************************************************************/


inline const Foam::PtrList<Foam::volScalarField>& Foam::force::Kd() const
{
    return Kd_;
}


inline const Foam::PtrList<Foam::volVectorField>& Foam::force::liftF() const
{
    return liftF_;
}


inline const Foam::PtrList<Foam::volVectorField>& 
Foam::force::wallLubF() const
{
    return wallLubF_;
}


inline const Foam::PtrList<Foam::volVectorField>& 
Foam::force::turbulentDisF() const
{
    return turbulentDisF_;
}


template<class Type>
inline void Foam::force::updateRe(const Type& p)
{
    Re_[p.kth()][p.cellI()] = p.magUr()*p.d()*p.rhoc()/p.muc();
}
