/*******************************************************************************
@GPBEFoam:           3D fully coupled Eulerian-QBMM library for multiphase flows

@Authors:            Dongyue Li (HZDR & Dyfluid, Programmer)
                     Daniele Marchisio (Politecnico di Torino, Co-PI)
                     Christian Hasse (TU Darmstadt, Co-PI)
                     Dirk Lucas (Helmholtz-Zentrum Dresden-Rossendorf, Investor)

@Reference:  	     D. Li, D. Marchisio, C. Hasse, D. Lucas, twoWayGPBEFoam and 
                     oneWayGPBEFoam: open-source Eulerian-QBMM solvers for 
                     multiphase flows. Computer Physics Communication, Submitted

@History:            ver 1.0, 07/31/18 

@Info:	             The released Eulerian-QBMM library is based on OpenFOAM-5.x 
                     oneWayGPBEFoam can be employed to simulate one-way coupled 
                     problems. twoWayGPBEFoam can be employed to simulate
                     two-way coupled problems.
*******************************************************************************/

#ifndef constantCoefficient_H
#define constantCoefficient_H

#include "lift.H"


namespace Foam
{

namespace liftModels
{


class constantCoefficient
:
    public lift
{
    //- Private data

        //- Surface tension
        scalar Cl_;


public:

    //- Runtime type information
    TypeName("constantCoefficient");

    //- Constructers

        constantCoefficient
        (
            const dictionary& liftModels,
            const fvMesh& mesh
        );

        virtual ~constantCoefficient()
        {}


    //- Member functions

        //- Update the lift force
        virtual vector F
        (
            const label& cellI,
            const scalar& rhod,
            const scalar& rhoc,
            const scalar& diameter,
            const scalar& phaseF,
            const scalar& Re,
            const vector Uc,
            const vector Ud,
            const vector curlUc
        );
};


} // End namespace Foam


} // End namespace liftModels


#endif
