/*******************************************************************************
@GPBEFoam:           3D fully coupled Eulerian-QBMM library for multiphase flows

@Authors:            Dongyue Li (HZDR & Dyfluid, Programmer)
                     Daniele Marchisio (Politecnico di Torino, Co-PI)
                     Christian Hasse (TU Darmstadt, Co-PI)
                     Dirk Lucas (Helmholtz-Zentrum Dresden-Rossendorf, Investor)

@Reference:  	     D. Li, D. Marchisio, C. Hasse, D. Lucas, twoWayGPBEFoam and 
                     oneWayGPBEFoam: open-source Eulerian-QBMM solvers for 
                     multiphase flows. Computer Physics Communication, Submitted

@History:            ver 1.0, 07/31/18 

@Info:	             The released Eulerian-QBMM library is based on OpenFOAM-5.x 
                     oneWayGPBEFoam can be employed to simulate one-way coupled 
                     problems. twoWayGPBEFoam can be employed to simulate
                     two-way coupled problems.
*******************************************************************************/

#include "lift.H"
#include "zeroGradientFvPatchFields.H"


namespace Foam
{
    namespace liftModels
    {
    
        defineTypeNameAndDebug(lift, 0);
        defineRunTimeSelectionTable(lift, dictionary);
    
    }
}


Foam::liftModels::lift::lift
(
    const dictionary& forceModels,
    const fvMesh& mesh
)
:
    liftModels_(forceModels.subDict("liftModels")),
    wallDis_(mesh)
{}


Foam::autoPtr<Foam::liftModels::lift> 
Foam::liftModels::lift::New
(
    const dictionary& forceModels,
    const fvMesh& mesh
)
{
    const word modelType(forceModels.subDict("liftModels").lookup("liftModel"));

    Info << "Selecting lift model " << modelType 
        << endl;

    dictionaryConstructorTable::iterator cstrIter =
        dictionaryConstructorTablePtr_->find(modelType);

    if (cstrIter == dictionaryConstructorTablePtr_->end())
    {
        FatalErrorInFunction
            << "Unknown lift type "
            << modelType << nl << nl
            << "Valid lifts are : " << endl
            << dictionaryConstructorTablePtr_->sortedToc()
            << exit(FatalError);
    }

    return autoPtr<lift>
        (cstrIter()(forceModels, mesh));
}
