/*******************************************************************************
@GPBEFoam:           3D fully coupled Eulerian-QBMM library for multiphase flows

@Authors:            Dongyue Li (HZDR & Dyfluid, Programmer)
                     Daniele Marchisio (Politecnico di Torino, Co-PI)
                     Christian Hasse (TU Darmstadt, Co-PI)
                     Dirk Lucas (Helmholtz-Zentrum Dresden-Rossendorf, Investor)

@Reference:  	     D. Li, D. Marchisio, C. Hasse, D. Lucas, twoWayGPBEFoam and 
                     oneWayGPBEFoam: open-source Eulerian-QBMM solvers for 
                     multiphase flows. Computer Physics Communication, Submitted

@History:            ver 1.0, 07/31/18 

@Info:	             The released Eulerian-QBMM library is based on OpenFOAM-5.x 
                     oneWayGPBEFoam can be employed to simulate one-way coupled 
                     problems. twoWayGPBEFoam can be employed to simulate
                     two-way coupled problems.
*******************************************************************************/

#ifndef lift_H
#define lift_H

#include "dictionary.H"
#include "runTimeSelectionTables.H"
#include "volFields.H"
#include "wallDependentModel.H"


namespace Foam
{

namespace liftModels
{


class lift
{


protected:

    //- Protected data

        //- Dictionary for lift model
        dictionary liftModels_;	

        //- Wall depended Model
        wallDependentModel wallDis_;


    //- Protected member functions

        //- Disallow copy construct
        lift(const lift&);

        //- Disallow default bitwise assignment
        void operator=(const lift&);


public:

    //- Runtime type information
    TypeName("lift");

    //- Public member functions

        //- Declare run-time constructor selection table
        declareRunTimeSelectionTable
        (
            autoPtr,
            lift,
            dictionary,
            (
                const dictionary& forceModels,
                const fvMesh& mesh
            ),
            (forceModels, mesh)
        );

        //- Return a reference to the selected drag model
        static autoPtr<lift> New
        (
            const dictionary& forceModels,
            const fvMesh& mesh
        );


    //- Construct from components

        lift
        (
            const dictionary& forceModels,
            const fvMesh& mesh
        );

        virtual ~lift()
        {}


    //- Member functions

        //- Update the lift force
        virtual vector F
        (
            const label& cellI,
            const scalar& rhod,
            const scalar& rhoc,
            const scalar& diameter,
            const scalar& phaseF,
            const scalar& Re,
            const vector Uc,
            const vector Ud,
            const vector curlUc
        ) = 0;
};


} // End namespace Foam


} // End namespace liftModels


#endif
