/*******************************************************************************
@GPBEFoam:           3D fully coupled Eulerian-QBMM library for multiphase flows

@Authors:            Dongyue Li (HZDR & Dyfluid, Programmer)
                     Daniele Marchisio (Politecnico di Torino, Co-PI)
                     Christian Hasse (TU Darmstadt, Co-PI)
                     Dirk Lucas (Helmholtz-Zentrum Dresden-Rossendorf, Investor)

@Reference:  	     D. Li, D. Marchisio, C. Hasse, D. Lucas, twoWayGPBEFoam and 
                     oneWayGPBEFoam: open-source Eulerian-QBMM solvers for 
                     multiphase flows. Computer Physics Communication, Submitted

@History:            ver 1.0, 07/31/18 

@Info:	             The released Eulerian-QBMM library is based on OpenFOAM-5.x 
                     oneWayGPBEFoam can be employed to simulate one-way coupled 
                     problems. twoWayGPBEFoam can be employed to simulate
                     two-way coupled problems.
*******************************************************************************/

#include "noneLift.H"
#include "addToRunTimeSelectionTable.H"


namespace Foam
{
    namespace liftModels
    {
        defineTypeNameAndDebug(none, 0);
    
        addToRunTimeSelectionTable
        (
            lift,
            none,
            dictionary
        );
    }
}


Foam::vector Foam::liftModels::none::F
(
    const label& cellI,
    const scalar& rhod,
    const scalar& rhoc,
    const scalar& diameter,
    const scalar& phaseF,
    const scalar& Re,
    const vector Uc,
    const vector Ud,
    const vector curlUc
)
{
    return Zero;
}


Foam::liftModels::none::none
(
    const dictionary& liftModels,
    const fvMesh& mesh
)
:
    lift(liftModels, mesh)
{}
