/*******************************************************************************
@GPBEFoam:           3D fully coupled Eulerian-QBMM library for multiphase flows

@Authors:            Dongyue Li (HZDR & Dyfluid, Programmer)
                     Daniele Marchisio (Politecnico di Torino, Co-PI)
                     Christian Hasse (TU Darmstadt, Co-PI)
                     Dirk Lucas (Helmholtz-Zentrum Dresden-Rossendorf, Investor)

@Reference:  	     D. Li, D. Marchisio, C. Hasse, D. Lucas, twoWayGPBEFoam and 
                     oneWayGPBEFoam: open-source Eulerian-QBMM solvers for 
                     multiphase flows. Computer Physics Communication, Submitted

@History:            ver 1.0, 07/31/18 

@Info:	             The released Eulerian-QBMM library is based on OpenFOAM-5.x 
                     oneWayGPBEFoam can be employed to simulate one-way coupled 
                     problems. twoWayGPBEFoam can be employed to simulate
                     two-way coupled problems.
*******************************************************************************/

#include "lopezDeBertodano.H"
#include "addToRunTimeSelectionTable.H"


namespace Foam
{
    namespace turbulentDispersionModels
    {
        defineTypeNameAndDebug(lopezDeBertodano, 0);
    
        addToRunTimeSelectionTable
        (
            turbulentDispersion,
            lopezDeBertodano,
            dictionary
        );
    }
}


Foam::vector Foam::turbulentDispersionModels::lopezDeBertodano::F
(
    const label& cellI,
    const scalar& k,
    const scalar& rhoc,
    const vector* gradPhaseFraction,
    const scalar& phaseFraction,
    const scalar& diameter,
    const label& kth,
    const scalar& nut,
    const scalar magUr
)
{
    return -Ctd_*k*rhoc*gradPhaseFraction[kth]/phaseFraction;
}


Foam::turbulentDispersionModels::lopezDeBertodano::lopezDeBertodano
(
    const dictionary& turbulentDispersionModels,
    const fvMesh& mesh
)
:
    turbulentDispersion(turbulentDispersionModels, mesh),
    Ctd_(readScalar(turbulentDispersionModels_.lookup("Ctd")))
{}
