/*******************************************************************************
@GPBEFoam:           3D fully coupled Eulerian-QBMM library for multiphase flows

@Authors:            Dongyue Li (HZDR & Dyfluid, Programmer)
                     Daniele Marchisio (Politecnico di Torino, Co-PI)
                     Christian Hasse (TU Darmstadt, Co-PI)
                     Dirk Lucas (Helmholtz-Zentrum Dresden-Rossendorf, Investor)

@Reference:  	     D. Li, D. Marchisio, C. Hasse, D. Lucas, twoWayGPBEFoam and 
                     oneWayGPBEFoam: open-source Eulerian-QBMM solvers for 
                     multiphase flows. Computer Physics Communication, Submitted

@History:            ver 1.0, 07/31/18 

@Info:	             The released Eulerian-QBMM library is based on OpenFOAM-5.x 
                     oneWayGPBEFoam can be employed to simulate one-way coupled 
                     problems. twoWayGPBEFoam can be employed to simulate
                     two-way coupled problems.
*******************************************************************************/


#include "noneTurbulentDispersion.H"
#include "addToRunTimeSelectionTable.H"


namespace Foam
{

namespace turbulentDispersionModels
{

    defineTypeNameAndDebug(none, 0);

    addToRunTimeSelectionTable
    (
        turbulentDispersion,
        none,
        dictionary
	);

}

}


Foam::vector Foam::turbulentDispersionModels::none::F
(
    const label& cellI,
    const scalar& k,
    const scalar& rhoc,
    const vector* gradPhaseFraction,
    const scalar& phaseFraction,
    const scalar& diameter,
    const label& kth,
    const scalar& nut,
    const scalar magUr 
)
{
    return Zero;
}


Foam::turbulentDispersionModels::none::none
(
	const dictionary& turbulentDispersionModels,
	const fvMesh& mesh
)
:
    turbulentDispersion(turbulentDispersionModels, mesh)
{}
