/*******************************************************************************
@GPBEFoam:           3D fully coupled Eulerian-QBMM library for multiphase flows

@Authors:            Dongyue Li (HZDR & Dyfluid, Programmer)
                     Daniele Marchisio (Politecnico di Torino, Co-PI)
                     Christian Hasse (TU Darmstadt, Co-PI)
                     Dirk Lucas (Helmholtz-Zentrum Dresden-Rossendorf, Investor)

@Reference:  	     D. Li, D. Marchisio, C. Hasse, D. Lucas, twoWayGPBEFoam and 
                     oneWayGPBEFoam: open-source Eulerian-QBMM solvers for 
                     multiphase flows. Computer Physics Communication, Submitted

@History:            ver 1.0, 07/31/18 

@Info:	             The released Eulerian-QBMM library is based on OpenFOAM-5.x 
                     oneWayGPBEFoam can be employed to simulate one-way coupled 
                     problems. twoWayGPBEFoam can be employed to simulate
                     two-way coupled problems.
*******************************************************************************/

#include "turbulentDispersion.H"
#include "zeroGradientFvPatchFields.H"


namespace Foam
{
    namespace turbulentDispersionModels
    {
    
        defineTypeNameAndDebug(turbulentDispersion, 0);
        defineRunTimeSelectionTable(turbulentDispersion, dictionary);
    }
}


Foam::turbulentDispersionModels::turbulentDispersion::turbulentDispersion
(
    const dictionary& forceModels,
    const fvMesh& mesh
)
:
    turbulentDispersionModels_(forceModels.subDict("turbulentDispersionModels")),
    mesh_(mesh)
{}


Foam::autoPtr<Foam::turbulentDispersionModels::turbulentDispersion>
Foam::turbulentDispersionModels::turbulentDispersion::New
(
    const dictionary& forceModels,
    const fvMesh& mesh
)
{
    const word modelType(forceModels.subDict("turbulentDispersionModels").lookup("turbulentDispersionModel"));

    Info << "Selecting turbulentDispersion model " << modelType 
        << endl;

    dictionaryConstructorTable::iterator cstrIter =
        dictionaryConstructorTablePtr_->find(modelType);

    if (cstrIter == dictionaryConstructorTablePtr_->end())
    {
        FatalErrorInFunction
            << "Unknown turbulentDispersion type "
            << modelType << nl << nl
            << "Valid turbulentDispersions are : " << endl
            << dictionaryConstructorTablePtr_->sortedToc()
            << exit(FatalError);
    }

    return autoPtr<turbulentDispersion>
        (cstrIter()(forceModels, mesh));
}
