/*******************************************************************************
@GPBEFoam:           3D fully coupled Eulerian-QBMM library for multiphase flows

@Authors:            Dongyue Li (HZDR & Dyfluid, Programmer)
                     Daniele Marchisio (Politecnico di Torino, Co-PI)
                     Christian Hasse (TU Darmstadt, Co-PI)
                     Dirk Lucas (Helmholtz-Zentrum Dresden-Rossendorf, Investor)

@Reference:  	     D. Li, D. Marchisio, C. Hasse, D. Lucas, twoWayGPBEFoam and 
                     oneWayGPBEFoam: open-source Eulerian-QBMM solvers for 
                     multiphase flows. Computer Physics Communication, Submitted

@History:            ver 1.0, 07/31/18 

@Info:	             The released Eulerian-QBMM library is based on OpenFOAM-5.x 
                     oneWayGPBEFoam can be employed to simulate one-way coupled 
                     problems. twoWayGPBEFoam can be employed to simulate
                     two-way coupled problems.
*******************************************************************************/

#ifndef turbulentDispersion_H
#define turbulentDispersion_H

#include "dictionary.H"
#include "runTimeSelectionTables.H"
#include "volFields.H"


namespace Foam
{

namespace turbulentDispersionModels
{

class turbulentDispersion
{

protected:

    //- Protected data

        //- Dictionary for turbulentDispersion model
        dictionary turbulentDispersionModels_;	

        //- Mesh
        const fvMesh& mesh_;


    //- Protected member functions

        //- Disallow copy construct
        turbulentDispersion(const turbulentDispersion&);

        //- Disallow default bitwise assignment
        void operator=(const turbulentDispersion&);


public:

    //- Runtime type information
    TypeName("turbulentDispersion");

        declareRunTimeSelectionTable
        (
            autoPtr,
            turbulentDispersion,
            dictionary,
            (
                const dictionary& forceModels,
                const fvMesh& mesh
            ),
            (forceModels, mesh)
        );

        static autoPtr<turbulentDispersion> New
        (
            const dictionary& forceModels,
	    const fvMesh& mesh
        );


    //- Constructers

        turbulentDispersion
        (
            const dictionary& forceModels,
            const fvMesh& mesh
        );

        virtual ~turbulentDispersion()
        {}


    //- Member functions
        
        //- Update the turbulentDispersion force
        virtual vector F
        (
            const label& cellI,
            const scalar& k,
            const scalar& rhoc,
            const vector* gradPhaseFraction,
            const scalar& phaseFraction,
            const scalar& diameter,
            const label& kth,
            const scalar& nut,
            const scalar magUr
       ) = 0;
};


} // End namespace Foam


} // End namespace turbulenceDispersionModels


#endif
