/*******************************************************************************
@GPBEFoam:           3D fully coupled Eulerian-QBMM library for multiphase flows

@Authors:            Dongyue Li (HZDR & Dyfluid, Programmer)
                     Daniele Marchisio (Politecnico di Torino, Co-PI)
                     Christian Hasse (TU Darmstadt, Co-PI)
                     Dirk Lucas (Helmholtz-Zentrum Dresden-Rossendorf, Investor)

@Reference:  	     D. Li, D. Marchisio, C. Hasse, D. Lucas, twoWayGPBEFoam and 
                     oneWayGPBEFoam: open-source Eulerian-QBMM solvers for 
                     multiphase flows. Computer Physics Communication, Submitted

@History:            ver 1.0, 07/31/18 

@Info:	             The released Eulerian-QBMM library is based on OpenFOAM-5.x 
                     oneWayGPBEFoam can be employed to simulate one-way coupled 
                     problems. twoWayGPBEFoam can be employed to simulate
                     two-way coupled problems.
*******************************************************************************/

#include "Antal.H"
#include "addToRunTimeSelectionTable.H"


namespace Foam
{
    namespace wallLubricationModels
    {
        defineTypeNameAndDebug(Antal, 0);
    
        addToRunTimeSelectionTable
        (
            wallLubrication,
            Antal,
            dictionary
        );
    }
}


Foam::vector Foam::wallLubricationModels::Antal::F
(
    const label& cellI,
    const scalar& rhod,
    const scalar& rhoc,
    const scalar& diameter,
    const scalar& phaseF,
    const scalar& alpha,
    const scalar& Re,
    const vector& Ur	
)
{
    const vector n(-nWall()[cellI]);

    C_[cellI] = max(0, Cw1_/diameter + Cw2_/yWall()[cellI]);

    if (alpha > 1e-5)
    {
        return phaseF*C_[cellI]*rhoc*magSqr(-Ur - ((-Ur) & n)*n)*n;
    }
    else 
    {
        return Zero;
    }
}


Foam::wallLubricationModels::Antal::Antal
(
    const dictionary& wallLubricationModels,
    const fvMesh& mesh
)
:
    wallLubrication(wallLubricationModels, mesh),
    surfaceT_(readScalar(wallLubricationModels_.lookup("surfaceTension"))),
    Cw1_(readScalar(wallLubricationModels_.lookup("Cw1"))),
    Cw2_(readScalar(wallLubricationModels_.lookup("Cw2")))
{}
