/*******************************************************************************
@GPBEFoam:           3D fully coupled Eulerian-QBMM library for multiphase flows

@Authors:            Dongyue Li (HZDR & Dyfluid, Programmer)
                     Daniele Marchisio (Politecnico di Torino, Co-PI)
                     Christian Hasse (TU Darmstadt, Co-PI)
                     Dirk Lucas (Helmholtz-Zentrum Dresden-Rossendorf, Investor)

@Reference:  	     D. Li, D. Marchisio, C. Hasse, D. Lucas, twoWayGPBEFoam and 
                     oneWayGPBEFoam: open-source Eulerian-QBMM solvers for 
                     multiphase flows. Computer Physics Communication, Submitted

@History:            ver 1.0, 07/31/18 

@Info:	             The released Eulerian-QBMM library is based on OpenFOAM-5.x 
                     oneWayGPBEFoam can be employed to simulate one-way coupled 
                     problems. twoWayGPBEFoam can be employed to simulate
                     two-way coupled problems.
*******************************************************************************/

#include "constantWallCoefficient.H"
#include "addToRunTimeSelectionTable.H"


namespace Foam
{
    namespace wallLubricationModels
    {
        defineTypeNameAndDebug(constantWallCoefficient, 0);
    
        addToRunTimeSelectionTable
        (
            wallLubrication,
            constantWallCoefficient,
            dictionary
        );
    }
}


Foam::vector Foam::wallLubricationModels::constantWallCoefficient::F
(
    const label& cellI,
    const scalar& rhod,
    const scalar& rhoc,
    const scalar& diameter,
    const scalar& phaseF,
    const scalar& alpha,
    const scalar& Re,
    const vector& Ur	
)
{
    const vector n(-nWall()[cellI]);

    return phaseF*C1_*rhoc*magSqr(Ur - ((Ur) & n)*n)*n;
}


Foam::wallLubricationModels::constantWallCoefficient::constantWallCoefficient
(
    const dictionary& wallLubricationModels,
    const fvMesh& mesh
)
:
    wallLubrication(wallLubricationModels, mesh),
    C1_(readScalar(wallLubricationModels_.lookup("C1")))
{}
