/*******************************************************************************
@GPBEFoam:           3D fully coupled Eulerian-QBMM library for multiphase flows

@Authors:            Dongyue Li (HZDR & Dyfluid, Programmer)
                     Daniele Marchisio (Politecnico di Torino, Co-PI)
                     Christian Hasse (TU Darmstadt, Co-PI)
                     Dirk Lucas (Helmholtz-Zentrum Dresden-Rossendorf, Investor)

@Reference:  	     D. Li, D. Marchisio, C. Hasse, D. Lucas, twoWayGPBEFoam and 
                     oneWayGPBEFoam: open-source Eulerian-QBMM solvers for 
                     multiphase flows. Computer Physics Communication, Submitted

@History:            ver 1.0, 07/31/18 

@Info:	             The released Eulerian-QBMM library is based on OpenFOAM-5.x 
                     oneWayGPBEFoam can be employed to simulate one-way coupled 
                     problems. twoWayGPBEFoam can be employed to simulate
                     two-way coupled problems.
*******************************************************************************/

#include "noneWallLubrication.H"
#include "addToRunTimeSelectionTable.H"


namespace Foam
{
    namespace wallLubricationModels
    {
        defineTypeNameAndDebug(none, 0);
    
        addToRunTimeSelectionTable
        (
            wallLubrication,
            none,
            dictionary
    	);
    }
}


Foam::vector Foam::wallLubricationModels::none::F
(
    const label& cellI,
    const scalar& rhod,
    const scalar& rhoc,
    const scalar& diameter,
    const scalar& phaseF,
    const scalar& alpha,
    const scalar& Re,
    const vector& Ur	
)
{
    return vector(0,0,0);
}


Foam::wallLubricationModels::none::none
(
    const dictionary& wallLubricationModels,
    const fvMesh& mesh
)
:
    wallLubrication(wallLubricationModels, mesh)
{}
