/*******************************************************************************
@GPBEFoam:           3D fully coupled Eulerian-QBMM library for multiphase flows

@Authors:            Dongyue Li (HZDR & Dyfluid, Programmer)
                     Daniele Marchisio (Politecnico di Torino, Co-PI)
                     Christian Hasse (TU Darmstadt, Co-PI)
                     Dirk Lucas (Helmholtz-Zentrum Dresden-Rossendorf, Investor)

@Reference:  	     D. Li, D. Marchisio, C. Hasse, D. Lucas, twoWayGPBEFoam and 
                     oneWayGPBEFoam: open-source Eulerian-QBMM solvers for 
                     multiphase flows. Computer Physics Communication, Submitted

@History:            ver 1.0, 07/31/18 

@Info:	             The released Eulerian-QBMM library is based on OpenFOAM-5.x 
                     oneWayGPBEFoam can be employed to simulate one-way coupled 
                     problems. twoWayGPBEFoam can be employed to simulate
                     two-way coupled problems.
*******************************************************************************/

#ifndef wallLubrication_H
#define wallLubrication_H

#include "dictionary.H"
#include "runTimeSelectionTables.H"
#include "volFields.H"


namespace Foam
{

namespace wallLubricationModels
{

class wallLubrication
{
protected:

    //- Protected data

	//- Dictionary for wallLubrication model
	dictionary wallLubricationModels_;	

	//- Mesh
	const fvMesh& mesh_;

	//- C
	volScalarField C_;

		
    //- Protected member functions

        //- Disallow copy construct
        wallLubrication(const wallLubrication&);

        //- Disallow default bitwise assignment
        void operator=(const wallLubrication&);


public:

    //- Runtime type information
    TypeName("wallLubrication");

        declareRunTimeSelectionTable
        (
            autoPtr,
            wallLubrication,
            dictionary,
            (
                const dictionary& forceModels,
                const fvMesh& mesh
            ),
            (forceModels, mesh)
        );

        static autoPtr<wallLubrication> New
        (
            const dictionary& forceModels,
            const fvMesh& mesh
        );


    //- Construct from components

        wallLubrication
        (
            const dictionary& forceModels,
            const fvMesh& mesh
        );

        virtual ~wallLubrication()
        {}


    //- Member functions

        //- Update the wallLubrication Cl
        virtual vector F
        (
            const label& cellI,
            const scalar& rhod,
            const scalar& rhoc,
            const scalar& diameter,
            const scalar& phaseF,
            const scalar& alpha,
            const scalar& Re,
            const vector& Ur	
        ) = 0;

        // Return the wall distance, creating and storing it if necessary
        const volScalarField& yWall() const;

        // Return the wall normal, creating and storing it if necessary
        const volVectorField& nWall() const;
};


} // End namespace Foam


} // End namespace wallLubricationModels


#endif
