/*******************************************************************************
@GPBEFoam:      3D fully coupled Eulerian-QBMM library for multiphase flows

@Authors:       Dongyue Li (HZDR & Dyfluid, Programmer)
                Daniele Marchisio (Politecnico di Torino, Co-PI)
                Christian Hasse (TU Darmstadt, Co-PI)
                Dirk Lucas (Helmholtz-Zentrum Dresden-Rossendorf, Investor)

@Reference:     D. Li, D. Marchisio, C. Hasse, D. Lucas, twoWayGPBEFoam and 
                oneWayGPBEFoam: open-source Eulerian-QBMM solvers for multiphase 
                flows. Computer Physics Communication, Submitted

@History:       ver 1.0, 07/31/18 

@Info:          The released Eulerian-QBMM library is based on OpenFOAM-5.x. 
                oneWayGPBEFoam can be employed to simulate one-way coupled 
                problems. twoWayGPBEFoam can be employed to simulate two-way 
                coupled problems.
*******************************************************************************/

#ifndef LaakkonenBreakage_H
#define LaakkonenBreakage_H

#include "breakageModel.H"


namespace Foam
{

class LaakkonenBreakage
:
    public breakageModel
{
    //- Private data
    
        //- Optional coefficient C1, defaults to 6.0
        dimensionedScalar C1_;

        //- Optional coefficient C2, defaults to 0.04
        dimensionedScalar C2_;

        //- Optional coefficient C3, defaults to 0.01
        dimensionedScalar C3_;


protected:

    //- Protected member functions

        //- Disallow copy construct
        LaakkonenBreakage(const LaakkonenBreakage&);

        //- Disallow default bitwise assignment
        void operator=(const LaakkonenBreakage&);


public:

    //- Runtime type information
    TypeName("LaakkonenBreakage");   


    //- Constructers

        LaakkonenBreakage
        (
            const dictionary& breakageModelProperties,
            const fvMesh& mesh
        );

        virtual ~LaakkonenBreakage()
        {}


    //- Member functions

        //- Return breakage frequency
        void updateBreakage
        (
            PtrList<volScalarField>& w,
            PtrList<volScalarField>& a
        );

};


} // End namespace Foam


#endif
