/*******************************************************************************
@GPBEFoam:      3D fully coupled Eulerian-QBMM library for multiphase flows

@Authors:       Dongyue Li (HZDR & Dyfluid, Programmer)
                Daniele Marchisio (Politecnico di Torino, Co-PI)
                Christian Hasse (TU Darmstadt, Co-PI)
                Dirk Lucas (Helmholtz-Zentrum Dresden-Rossendorf, Investor)

@Reference:     D. Li, D. Marchisio, C. Hasse, D. Lucas, twoWayGPBEFoam and 
                oneWayGPBEFoam: open-source Eulerian-QBMM solvers for multiphase 
                flows. Computer Physics Communication, Submitted

@History:       ver 1.0, 07/31/18 

@Info:          The released Eulerian-QBMM library is based on OpenFOAM-5.x. 
                oneWayGPBEFoam can be employed to simulate one-way coupled 
                problems. twoWayGPBEFoam can be employed to simulate two-way 
                coupled problems.
*******************************************************************************/

#include "LehrBreakage.H"
#include "addToRunTimeSelectionTable.H"


namespace Foam
{
    defineTypeNameAndDebug(LehrBreakage, 0);

    addToRunTimeSelectionTable
    (
        breakageModel,
        LehrBreakage,
        dictionary
    );
}


void Foam::LehrBreakage::updateBreakage
(
    PtrList<volScalarField>& w,
    PtrList<volScalarField>& a
)
{
    const volScalarField& rhoc =  
        a[0].db().lookupObject<volScalarField>("rho.water");

    const volScalarField& epsilon =  
        a[0].db().lookupObject<volScalarField>("epsilon.water");

    for (int n = 0; n < 3; n++)
    {
        volScalarField resetDim
        (
            0.5*pow(a[n], 5.0/3.0)*pow(epsilon, 2.0/3.0)
           *pow(rhoc/sigma_, 7.0/5.0)
        );

        resetDim.dimensions().reset(inv(dimTime));
 
        g_[n].ref() = 
            resetDim*exp
            (
               -sqrt(2.0)*pow(sigma_/rhoc, 9.0/5.0)
               /pow3(a[n])/pow(epsilon, 6.0/5.0)
            );
    }
}


Foam::LehrBreakage::LehrBreakage
(
    const dictionary& breakageModelProperties,
    const fvMesh& mesh
)
:
    breakageModel(breakageModelProperties, mesh)
{}
