/*******************************************************************************
@GPBEFoam:      3D fully coupled Eulerian-QBMM library for multiphase flows

@Authors:       Dongyue Li (HZDR & Dyfluid, Programmer)
                Daniele Marchisio (Politecnico di Torino, Co-PI)
                Christian Hasse (TU Darmstadt, Co-PI)
                Dirk Lucas (Helmholtz-Zentrum Dresden-Rossendorf, Investor)

@Reference:     D. Li, D. Marchisio, C. Hasse, D. Lucas, twoWayGPBEFoam and 
                oneWayGPBEFoam: open-source Eulerian-QBMM solvers for multiphase 
                flows. Computer Physics Communication, Submitted

@History:       ver 1.0, 07/31/18 

@Info:          The released Eulerian-QBMM library is based on OpenFOAM-5.x. 
                oneWayGPBEFoam can be employed to simulate one-way coupled 
                problems. twoWayGPBEFoam can be employed to simulate two-way 
                coupled problems.
*******************************************************************************/

#ifndef LehrBreakage_H
#define LehrBreakage_H

#include "breakageModel.H"


namespace Foam
{

class LehrBreakage
:
    public breakageModel
{
    //- Private data
    
        
protected:

    //- Protected member functions

        //- Disallow copy construct
        LehrBreakage(const LehrBreakage&);

        //- Disallow default bitwise assignment
        void operator=(const LehrBreakage&);


public:

    //- Runtime type information
    TypeName("LehrBreakage");   


    //- Constructers

        LehrBreakage
        (
            const dictionary& breakageModelProperties,
            const fvMesh& mesh
        );

        virtual ~LehrBreakage()
        {}


    //- Member functions

        //- Return breakage frequency
        void updateBreakage
        (
            PtrList<volScalarField>& w,
            PtrList<volScalarField>& a
        );

};


} // End namespace Foam


#endif
