/*******************************************************************************
@GPBEFoam:      3D fully coupled Eulerian-QBMM library for multiphase flows

@Authors:       Dongyue Li (HZDR & Dyfluid, Programmer)
                Daniele Marchisio (Politecnico di Torino, Co-PI)
                Christian Hasse (TU Darmstadt, Co-PI)
                Dirk Lucas (Helmholtz-Zentrum Dresden-Rossendorf, Investor)

@Reference:     D. Li, D. Marchisio, C. Hasse, D. Lucas, twoWayGPBEFoam and 
                oneWayGPBEFoam: open-source Eulerian-QBMM solvers for multiphase 
                flows. Computer Physics Communication, Submitted

@History:       ver 1.0, 07/31/18 

@Info:          The released Eulerian-QBMM library is based on OpenFOAM-5.x. 
                oneWayGPBEFoam can be employed to simulate one-way coupled 
                problems. twoWayGPBEFoam can be employed to simulate two-way 
                coupled problems.
*******************************************************************************/

#ifndef breakageModel_H
#define breakageModel_H

#include "scalarMatrices.H"
#include "volFields.H"


namespace Foam
{

class breakageModel
{
protected:
 
    //- fvMesh
    const fvMesh& mesh_;

    //- Breakage frequency
    PtrList<tmp<volScalarField>> g_;

    //- Surface tension
    dimensionedScalar sigma_;

    //- Disperse phase density
    dimensionedScalar rhod_;
    

    //- Protected member functions

        //- Disallow copy construct
        breakageModel(const breakageModel&);

        //- Disallow default bitwise assignment
        void operator=(const breakageModel&);


public:

    //- Runtime type information
    TypeName("breakageModel");

        declareRunTimeSelectionTable
        (
            autoPtr,
            breakageModel,
            dictionary,
            (
                const dictionary& breakageModelProperties,
                const fvMesh& mesh
            ),
            (breakageModelProperties, mesh)
        );

        static autoPtr<breakageModel> New
        (
            const dictionary& breakageModelProperties,
            const fvMesh& mesh
        );
        

    //- Construct from components

        breakageModel
        (
            const dictionary& breakageModelProperties,
            const fvMesh& mesh
        );

        virtual ~breakageModel()
        {}


    //- Member functions

        virtual void updateBreakage
        (
            PtrList<volScalarField>& w,
            PtrList<volScalarField>& a
        ) = 0;


    //- Inline functions
    
        //- Return breakage frequency
        inline const PtrList<tmp<volScalarField>>& g() const
        {
            return g_;
        }

};


} // End namespace Foam


#endif
