/*******************************************************************************
@GPBEFoam:      3D fully coupled Eulerian-QBMM library for multiphase flows

@Authors:       Dongyue Li (HZDR & Dyfluid, Programmer)
                Daniele Marchisio (Politecnico di Torino, Co-PI)
                Christian Hasse (TU Darmstadt, Co-PI)
                Dirk Lucas (Helmholtz-Zentrum Dresden-Rossendorf, Investor)

@Reference:     D. Li, D. Marchisio, C. Hasse, D. Lucas, twoWayGPBEFoam and 
                oneWayGPBEFoam: open-source Eulerian-QBMM solvers for multiphase 
                flows. Computer Physics Communication, Submitted

@History:       ver 1.0, 07/31/18 

@Info:          The released Eulerian-QBMM library is based on OpenFOAM-5.x. 
                oneWayGPBEFoam can be employed to simulate one-way coupled 
                problems. twoWayGPBEFoam can be employed to simulate two-way 
                coupled problems.
*******************************************************************************/

#include "constantBreakage.H"
#include "addToRunTimeSelectionTable.H"


namespace Foam
{
    defineTypeNameAndDebug(constantBreakage, 0);

    addToRunTimeSelectionTable
    (
        breakageModel,
        constantBreakage,
        dictionary
    );
}


Foam::constantBreakage::constantBreakage
(
    const dictionary& breakageModelProperties,
    const fvMesh& mesh
)
:
    breakageModel(breakageModelProperties, mesh)
{}


void Foam::constantBreakage::updateBreakage
(
    PtrList<volScalarField>& w,
    PtrList<volScalarField>& a
)
{
    for (int n = 0; n < 3; n++)
    {
        g_[n].ref().primitiveFieldRef() = sqr(a[n]);
    }
}
