/*******************************************************************************
@GPBEFoam:      3D fully coupled Eulerian-QBMM library for multiphase flows

@Authors:       Dongyue Li (HZDR & Dyfluid, Programmer)
                Daniele Marchisio (Politecnico di Torino, Co-PI)
                Christian Hasse (TU Darmstadt, Co-PI)
                Dirk Lucas (Helmholtz-Zentrum Dresden-Rossendorf, Investor)

@Reference:     D. Li, D. Marchisio, C. Hasse, D. Lucas, twoWayGPBEFoam and 
                oneWayGPBEFoam: open-source Eulerian-QBMM solvers for multiphase 
                flows. Computer Physics Communication, Submitted

@History:       ver 1.0, 07/31/18 

@Info:          The released Eulerian-QBMM library is based on OpenFOAM-5.x. 
                oneWayGPBEFoam can be employed to simulate one-way coupled 
                problems. twoWayGPBEFoam can be employed to simulate two-way 
                coupled problems.
*******************************************************************************/

#include "CTCoalescence.H"
#include "addToRunTimeSelectionTable.H"


namespace Foam
{
    defineTypeNameAndDebug(CTCoalescence, 0);

    addToRunTimeSelectionTable
    (
        coalescenceModel,
        CTCoalescence,
        dictionary
    );
}


const Foam::tmp<Foam::volScalarField>& Foam::CTCoalescence::agg
(
    const PtrList<volScalarField>& a,
    const int i,
    const int j
)
{    
    const volScalarField& rhoc =  
        a[0].db().lookupObject<volScalarField>("rho.water");

    const volScalarField& epsilon =  
        a[0].db().lookupObject<volScalarField>("epsilon.water");

    const volScalarField& muc =  
        a[0].db().lookupObject<volScalarField>("mu.water");

    collisionRate_.ref() =
        A1_*cbrt(epsilon)*sqr(a[i] + a[j])
       *sqrt(pow(a[i], 2.0/3.0) + pow(a[j], 2.0/3.0))
       *exp
        (
          - A2_*muc*rhoc*epsilon/sqr(sigma_)
           *pow(a[i]*a[j]/(a[i] + a[j]), 4.0)
        );

    return collisionRate_;
}


Foam::CTCoalescence::CTCoalescence
(
    const dictionary& coalescenceModelProperties,
    const fvMesh& mesh
)
:
    coalescenceModel(coalescenceModelProperties, mesh),
    A1_
    (
        "A1",
        dimless,
        readScalar(coalescenceModelProperties.lookup("A1"))
    ),
    A2_
    (
        "A2", 
        inv(dimArea), 
        readScalar(coalescenceModelProperties.lookup("A2"))
    )
{}


