/*******************************************************************************
@GPBEFoam:      3D fully coupled Eulerian-QBMM library for multiphase flows

@Authors:       Dongyue Li (HZDR & Dyfluid, Programmer)
                Daniele Marchisio (Politecnico di Torino, Co-PI)
                Christian Hasse (TU Darmstadt, Co-PI)
                Dirk Lucas (Helmholtz-Zentrum Dresden-Rossendorf, Investor)

@Reference:     D. Li, D. Marchisio, C. Hasse, D. Lucas, twoWayGPBEFoam and 
                oneWayGPBEFoam: open-source Eulerian-QBMM solvers for multiphase 
                flows. Computer Physics Communication, Submitted

@History:       ver 1.0, 07/31/18 

@Info:          The released Eulerian-QBMM library is based on OpenFOAM-5.x. 
                oneWayGPBEFoam can be employed to simulate one-way coupled 
                problems. twoWayGPBEFoam can be employed to simulate two-way 
                coupled problems.
*******************************************************************************/

#ifndef CTCoalescence_H
#define CTCoalescence_H

#include "coalescenceModel.H"


namespace Foam
{

class CTCoalescence
:
    public coalescenceModel
{
    //- Private data
    
        //- Optional coefficient C1, defaults to 6.0
        dimensionedScalar A1_;

        //- Optional coefficient C2, defaults to 0.04
        dimensionedScalar A2_;


protected:

    //- Protected member functions

        //- Disallow copy construct
        CTCoalescence(const CTCoalescence&);

        //- Disallow default bitwise assignment
        void operator=(const CTCoalescence&);


public:

    //- Runtime type information
    TypeName("CTCoalescence");   


    //- Constructers

        CTCoalescence
        (
            const dictionary& coalescenceModelProperties,
            const fvMesh& mesh
        );

        virtual ~CTCoalescence()
        {}


    //- Member functions

        virtual const tmp<volScalarField>& agg
        (
            const PtrList<volScalarField>& a,
            const int i,
            const int j
        );
};


} // End namespace Foam


#endif
