/*******************************************************************************
@GPBEFoam:      3D fully coupled Eulerian-QBMM library for multiphase flows

@Authors:       Dongyue Li (HZDR & Dyfluid, Programmer)
                Daniele Marchisio (Politecnico di Torino, Co-PI)
                Christian Hasse (TU Darmstadt, Co-PI)
                Dirk Lucas (Helmholtz-Zentrum Dresden-Rossendorf, Investor)

@Reference:     D. Li, D. Marchisio, C. Hasse, D. Lucas, twoWayGPBEFoam and 
                oneWayGPBEFoam: open-source Eulerian-QBMM solvers for multiphase 
                flows. Computer Physics Communication, Submitted

@History:       ver 1.0, 07/31/18 

@Info:          The released Eulerian-QBMM library is based on OpenFOAM-5.x. 
                oneWayGPBEFoam can be employed to simulate one-way coupled 
                problems. twoWayGPBEFoam can be employed to simulate two-way 
                coupled problems.
*******************************************************************************/

#ifndef PrinceBlanch_H
#define PrinceBlanch_H

#include "coalescenceModel.H"


namespace Foam
{

class PrinceBlanch
:
    public coalescenceModel
{
    //- Private data
    
        //- Optional coefficient h0, defaults to 1e-4
        dimensionedScalar h0_;

        //- Optional coefficient hf, defaults to 1e-8
        dimensionedScalar hf_;

        //- Optional coefficient C1, defaults to 0.089
        dimensionedScalar C1_;

        //- Turbulent collision
        Switch turbulentCollision_;

        //- Buoyant collision
        Switch buoyantCollision_;


protected:

    //- Protected member functions

        //- Disallow copy construct
        PrinceBlanch(const PrinceBlanch&);

        //- Disallow default bitwise assignment
        void operator=(const PrinceBlanch&);


public:

    //- Runtime type information
    TypeName("PrinceBlanch");   


    //- Constructers

        PrinceBlanch
        (
            const dictionary& coalescenceModelProperties,
            const fvMesh& mesh
        );

        virtual ~PrinceBlanch()
        {}


    //- Member functions

        virtual const tmp<volScalarField>& agg
        (
            const PtrList<volScalarField>& a,
            const int i,
            const int j
        );
};


} // End namespace Foam


#endif
