/*******************************************************************************
@GPBEFoam:      3D fully coupled Eulerian-QBMM library for multiphase flows

@Authors:       Dongyue Li (HZDR & Dyfluid, Programmer)
                Daniele Marchisio (Politecnico di Torino, Co-PI)
                Christian Hasse (TU Darmstadt, Co-PI)
                Dirk Lucas (Helmholtz-Zentrum Dresden-Rossendorf, Investor)

@Reference:     D. Li, D. Marchisio, C. Hasse, D. Lucas, twoWayGPBEFoam and 
                oneWayGPBEFoam: open-source Eulerian-QBMM solvers for multiphase 
                flows. Computer Physics Communication, Submitted

@History:       ver 1.0, 07/31/18 

@Info:          The released Eulerian-QBMM library is based on OpenFOAM-5.x. 
                oneWayGPBEFoam can be employed to simulate one-way coupled 
                problems. twoWayGPBEFoam can be employed to simulate two-way 
                coupled problems.
*******************************************************************************/

#ifndef coalescenceModel_H
#define coalescenceModel_H

#include "scalarMatrices.H"
#include "volFields.H"


namespace Foam
{

class coalescenceModel
{
protected:
 
    //- fvMesh
    const fvMesh& mesh_;

    //- Surface tension
    dimensionedScalar sigma_;

    //- Collision rate
    tmp<volScalarField> collisionRate_;

    //- Protected member functions

        //- Disallow copy construct
        coalescenceModel(const coalescenceModel&);

        //- Disallow default bitwise assignment
        void operator=(const coalescenceModel&);


public:

    //- Runtime type information
    TypeName("coalescenceModel");

        declareRunTimeSelectionTable
        (
            autoPtr,
            coalescenceModel,
            dictionary,
            (
                const dictionary& coalescenceModelProperties,
                const fvMesh& mesh
            ),
            (coalescenceModelProperties, mesh)
        );

        static autoPtr<coalescenceModel> New
        (
            const dictionary& coalescenceModelProperties,
            const fvMesh& mesh
        );
        

    //- Construct from components

        coalescenceModel
        (
            const dictionary& coalescenceModelProperties,
            const fvMesh& mesh
        );

        virtual ~coalescenceModel()
        {}


    //- Member functions

        virtual const tmp<volScalarField>& agg
        (
            const PtrList<volScalarField>& a,
            const int i,
            const int j
        ) = 0;


};


} // End namespace Foam


#endif
