/*******************************************************************************
@GPBEFoam:      3D fully coupled Eulerian-QBMM library for multiphase flows

@Authors:       Dongyue Li (HZDR & Dyfluid, Programmer)
                Daniele Marchisio (Politecnico di Torino, Co-PI)
                Christian Hasse (TU Darmstadt, Co-PI)
                Dirk Lucas (Helmholtz-Zentrum Dresden-Rossendorf, Investor)

@Reference:     D. Li, D. Marchisio, C. Hasse, D. Lucas, twoWayGPBEFoam and 
                oneWayGPBEFoam: open-source Eulerian-QBMM solvers for multiphase 
                flows. Computer Physics Communication, Submitted

@History:       ver 1.0, 07/31/18 

@Info:          The released Eulerian-QBMM library is based on OpenFOAM-5.x. 
                oneWayGPBEFoam can be employed to simulate one-way coupled 
                problems. twoWayGPBEFoam can be employed to simulate two-way 
                coupled problems.
*******************************************************************************/

#include "daughterSizeDistributionModel.H"
#include "zeroGradientFvPatchFields.H"

namespace Foam
{
    defineTypeNameAndDebug(daughterSizeDistributionModel, 0);
    defineRunTimeSelectionTable(daughterSizeDistributionModel, dictionary);
}


Foam::daughterSizeDistributionModel::daughterSizeDistributionModel
(
    const dictionary& daughterSizeDistributionModelProperties,
    const fvMesh& mesh
)
:
    beta_
    (
        new volScalarField
        (
            IOobject
            (
                "beta",
                mesh.time().timeName(),
                mesh,
                IOobject::NO_READ,
                IOobject::AUTO_WRITE
            ),
            mesh,
            dimensionedScalar
            (
                "beta",
                dimless,
                0.0
            ),
            zeroGradientFvPatchField<scalar>::typeName
        )
    )
{}


Foam::autoPtr<Foam::daughterSizeDistributionModel> Foam::daughterSizeDistributionModel::New
(
    const dictionary& daughterSizeDistributionModelProperties,
    const fvMesh& mesh
)
{
    Info<< "Foam::daughterSizeDistributionModel::New FUNCTION" << endl;

    const word modelType(daughterSizeDistributionModelProperties.lookup("daughterSizeDistributionModel"));

    Info<< "Selecting daughterSizeDistributionModel model is " << modelType << endl;

    dictionaryConstructorTable::iterator cstrIter =
        dictionaryConstructorTablePtr_->find(modelType);


    if (cstrIter == dictionaryConstructorTablePtr_->end())
    {
        FatalErrorInFunction
            << "Unknown daughterSizeDistributionModelModel type "
            << modelType << nl << nl
            << "Valid daughterSizeDistributionModel are : " << endl
            << dictionaryConstructorTablePtr_->sortedToc()
            << exit(FatalError);
    }

    return autoPtr<daughterSizeDistributionModel>
        (cstrIter()(daughterSizeDistributionModelProperties, mesh));
}
