/*******************************************************************************
@GPBEFoam:      3D fully coupled Eulerian-QBMM library for multiphase flows

@Authors:       Dongyue Li (HZDR & Dyfluid, Programmer)
                Daniele Marchisio (Politecnico di Torino, Co-PI)
                Christian Hasse (TU Darmstadt, Co-PI)
                Dirk Lucas (Helmholtz-Zentrum Dresden-Rossendorf, Investor)

@Reference:     D. Li, D. Marchisio, C. Hasse, D. Lucas, twoWayGPBEFoam and 
                oneWayGPBEFoam: open-source Eulerian-QBMM solvers for multiphase 
                flows. Computer Physics Communication, Submitted

@History:       ver 1.0, 07/31/18 

@Info:          The released Eulerian-QBMM library is based on OpenFOAM-5.x. 
                oneWayGPBEFoam can be employed to simulate one-way coupled 
                problems. twoWayGPBEFoam can be employed to simulate two-way 
                coupled problems.
*******************************************************************************/

#ifndef daughterSizeDistributionModel_H
#define daughterSizeDistributionModel_H

#include "scalarMatrices.H"
#include "volFields.H"


namespace Foam
{

class daughterSizeDistributionModel
{
protected:
 
    //- Daughter size distribution
    tmp<volScalarField> beta_;

    //- Protected member functions

        //- Disallow copy construct
        daughterSizeDistributionModel(const daughterSizeDistributionModel&);

        //- Disallow default bitwise assignment
        void operator=(const daughterSizeDistributionModel&);


public:

    //- Runtime type information
    TypeName("daughterSizeDistributionModel");

        declareRunTimeSelectionTable
        (
            autoPtr,
            daughterSizeDistributionModel,
            dictionary,
            (
                const dictionary& daughterSizeDistributionModelProperties,
                const fvMesh& mesh
            ),
            (daughterSizeDistributionModelProperties, mesh)
        );

        static autoPtr<daughterSizeDistributionModel> New
        (
            const dictionary& daughterSizeDistributionModelProperties,
            const fvMesh& mesh
        );
        

    //- Construct from components

        daughterSizeDistributionModel
        (
            const dictionary& daughterSizeDistributionModelProperties,
            const fvMesh& mesh
        );

        virtual ~daughterSizeDistributionModel()
        {}


    //- Member functions

        //- Return DSD
        virtual const tmp<volScalarField>& beta
        (
            const volScalarField& absN,
            const label kth
        ) = 0;
};


} // End namespace Foam


#endif
