/*******************************************************************************
@GPBEFoam:      3D fully coupled Eulerian-QBMM library for multiphase flows

@Authors:       Dongyue Li (HZDR & Dyfluid, Programmer)
                Daniele Marchisio (Politecnico di Torino, Co-PI)
                Christian Hasse (TU Darmstadt, Co-PI)
                Dirk Lucas (Helmholtz-Zentrum Dresden-Rossendorf, Investor)

@Reference:     D. Li, D. Marchisio, C. Hasse, D. Lucas, twoWayGPBEFoam and 
                oneWayGPBEFoam: open-source Eulerian-QBMM solvers for multiphase 
                flows. Computer Physics Communication, Submitted

@History:       ver 1.0, 07/31/18 

@Info:          The released Eulerian-QBMM library is based on OpenFOAM-5.x. 
                oneWayGPBEFoam can be employed to simulate one-way coupled 
                problems. twoWayGPBEFoam can be employed to simulate two-way 
                coupled problems.
*******************************************************************************/

#include "powDSD.H"
#include "addToRunTimeSelectionTable.H"


namespace Foam
{
    defineTypeNameAndDebug(powDSD, 0);

    addToRunTimeSelectionTable
    (
        daughterSizeDistributionModel,
        powDSD,
        dictionary
    );
}


const Foam::tmp<Foam::volScalarField>& Foam::powDSD::beta
(
    const volScalarField& absN,
    const label kth
)
{
    //- Reset DSD dimensions
    beta_.ref().dimensions().reset(dimensionSet(0,kth,0,0,0));

    beta_.ref() = 2.0*pow(absN, kth)/(kth + 1);

    return beta_;
}


Foam::powDSD::powDSD
(
    const dictionary& daughterSizeDistributionModelProperties,
    const fvMesh& mesh    
)
:
    daughterSizeDistributionModel(daughterSizeDistributionModelProperties, mesh)
{}
