/*******************************************************************************
@GPBEFoam:      3D fully coupled Eulerian-QBMM library for multiphase flows

@Authors:       Dongyue Li (HZDR & Dyfluid, Programmer)
                Daniele Marchisio (Politecnico di Torino, Co-PI)
                Christian Hasse (TU Darmstadt, Co-PI)
                Dirk Lucas (Helmholtz-Zentrum Dresden-Rossendorf, Investor)

@Reference:     D. Li, D. Marchisio, C. Hasse, D. Lucas, twoWayGPBEFoam and 
                oneWayGPBEFoam: open-source Eulerian-QBMM solvers for multiphase 
                flows. Computer Physics Communication, Submitted

@History:       ver 1.0, 07/31/18 

@Info:          The released Eulerian-QBMM library is based on OpenFOAM-5.x. 
                oneWayGPBEFoam can be employed to simulate one-way coupled 
                problems. twoWayGPBEFoam can be employed to simulate two-way 
                coupled problems.
*******************************************************************************/

#ifndef powDSD_H
#define powDSD_H

#include "daughterSizeDistributionModel.H"


namespace Foam
{

class powDSD
:
    public daughterSizeDistributionModel
{
    //- Private data
        

protected:

    //- Protected member functions

        //- Disallow copy construct
        powDSD(const powDSD&);

        //- Disallow default bitwise assignment
        void operator=(const powDSD&);


public:

    //- Runtime type information
    TypeName("powDSD");   


    //- Constructers

        powDSD
        (
            const dictionary& daughterSizeDistributionModelProperties,
            const fvMesh& mesh
        );

        virtual ~powDSD()
        {}


    //- Member functions

        //- Return DSD
        virtual const tmp<volScalarField>& beta
        (
            const volScalarField& absN,
            const label kth
        );

};


} // End namespace Foam


#endif
