/*******************************************************************************
@GPBEFoam:           3D fully coupled Eulerian-QBMM library for multiphase flows

@Authors:            Dongyue Li (HZDR & Dyfluid, Programmer)
                     Daniele Marchisio (Politecnico di Torino, Co-PI)
                     Christian Hasse (TU Darmstadt, Co-PI)
                     Dirk Lucas (Helmholtz-Zentrum Dresden-Rossendorf, Investor)

@Reference:          D. Li, D. Marchisio, C. Hasse, D. Lucas, twoWayGPBEFoam and 
                     oneWayGPBEFoam: open-source Eulerian-QBMM solvers for 
                     multiphase flows. Computer Physics Communication, Submitted

@History:            ver 1.0, 07/31/18 

@Info:               The released Eulerian-QBMM library is based on OpenFOAM-5.x 
                     oneWayGPBEFoam can be employed to simulate one-way coupled 
                     problems. twoWayGPBEFoam can be employed to simulate
                     two-way coupled problems.
*******************************************************************************/

#ifndef EulerImplicit_H
#define EulerImplicit_H

#include "timeScheme.H"


namespace Foam
{

class EulerImplicit
:
    public timeScheme
{
public:

    TypeName("EulerImplicit");

    //- Constructers

        EulerImplicit
        (
            const dictionary& QMOMProperties
        );

        virtual ~EulerImplicit()
        {}


    //- Member functions

        virtual void ODEresult
        (
            const scalar& dT,
            const scalar& phaseF,
            const vector& Uc,
            const scalar& Sp,
            const vector& Su,
            vector& result
        ); 
};


}


#endif
