/*******************************************************************************
@GPBEFoam:      3D fully coupled Eulerian-QBMM library for multiphase flows

@Authors:       Dongyue Li (HZDR & Dyfluid, Programmer)
                Daniele Marchisio (Politecnico di Torino, Co-PI)
                Christian Hasse (TU Darmstadt, Co-PI)
                Dirk Lucas (Helmholtz-Zentrum Dresden-Rossendorf, Investor)

@Reference:     D. Li, D. Marchisio, C. Hasse, D. Lucas, twoWayGPBEFoam and 
                oneWayGPBEFoam: open-source Eulerian-QBMM solvers for multiphase 
                flows. Computer Physics Communication, Submitted

@History:       ver 1.0, 07/31/18 

@Info:          The released Eulerian-QBMM library is based on OpenFOAM-5.x. 
                oneWayGPBEFoam can be employed to simulate one-way coupled 
                problems. twoWayGPBEFoam can be employed to simulate two-way 
                coupled problems.
*******************************************************************************/

#include "timeScheme.H"


namespace Foam
{
    defineTypeNameAndDebug(timeScheme, 0);
    defineRunTimeSelectionTable(timeScheme, dictionary);
}


Foam::timeScheme::timeScheme
(
    const dictionary& QMOMProperties
)
{}


Foam::autoPtr<Foam::timeScheme> Foam::timeScheme::New
(
    const dictionary& QMOMProperties
)
{
    const word modelType(QMOMProperties.lookup("timeScheme"));

    Info << "Selecting timeScheme model " << modelType 
        << endl;

    dictionaryConstructorTable::iterator cstrIter =
        dictionaryConstructorTablePtr_->find(modelType);

    if (cstrIter == dictionaryConstructorTablePtr_->end())
    {
        FatalErrorInFunction
            << "Unknown timeScheme type "
            << modelType << nl << nl
            << "Valid timeSchemes are : " << endl
            << dictionaryConstructorTablePtr_->sortedToc()
            << exit(FatalError);
    }

    return autoPtr<timeScheme>
        (cstrIter()(QMOMProperties));
}
