/*******************************************************************************
@GPBEFoam:           3D fully coupled Eulerian-QBMM library for multiphase flows

@Authors:            Dongyue Li (HZDR & Dyfluid, Programmer)
                     Daniele Marchisio (Politecnico di Torino, Co-PI)
                     Christian Hasse (TU Darmstadt, Co-PI)
                     Dirk Lucas (Helmholtz-Zentrum Dresden-Rossendorf, Investor)

@Reference:          D. Li, D. Marchisio, C. Hasse, D. Lucas, twoWayGPBEFoam and 
                     oneWayGPBEFoam: open-source Eulerian-QBMM solvers for 
                     multiphase flows. Computer Physics Communication, Submitted

@History:            ver 1.0, 07/31/18 

@Info:               The released Eulerian-QBMM library is based on OpenFOAM-5.x 
                     oneWayGPBEFoam can be employed to simulate one-way coupled 
                     problems. twoWayGPBEFoam can be employed to simulate
                     two-way coupled problems.
*******************************************************************************/

#ifndef timeScheme_H
#define timeScheme_H

#include "dictionary.H"
#include "runTimeSelectionTables.H"
#include "vector.H"


namespace Foam
{

class timeScheme
{
protected:

    //- Disallow copy construct
    timeScheme(const timeScheme&);

    //- Disallow default bitwise assignment
    void operator=(const timeScheme&);

public:

    //- Runtime type information
    TypeName("timeScheme");

        declareRunTimeSelectionTable
        (
            autoPtr,
            timeScheme,
            dictionary,
            (
                const dictionary& QMOMProperties
            ),
            (QMOMProperties)
        );

        static autoPtr<timeScheme> New
        (
            const dictionary& QMOMProperties
        );


    //- Constructers

        timeScheme
        (
            const dictionary& QMOMProperties
        );

        virtual ~timeScheme()
        {}


    //- Member functions

        virtual void ODEresult
        (
            const scalar& dT,
            const scalar& phaseF,
            const vector& Uc,
            const scalar& Sp,
            const vector& Su,
            vector& result
        ) = 0; 
};


}


#endif
